@@ -2,10 +2,8 @@
 # this repository contains the full copyright notices and license terms.
 
 from trytond.pool import Pool
-from . import ir
-from . import company
-from . import product
-from . import stock
+
+from . import account, company, ir, product, res, stock
 
 __all__ = ['register']
 
@@ -14,6 +12,7 @@ def register():
     Pool.register(
         ir.Cron,
         ir.CronWarehouse,
+        res.User,
         company.Company,
         product.Configuration,
         product.ConfigurationCostPriceWarehouse,
@@ -26,6 +25,10 @@ def register():
         stock.Move,
         stock.ShipmentInternal,
         module='product_cost_warehouse', type_='model')
+    Pool.register(
+        account.InvoiceLine,
+        module='product_cost_warehouse', type_='model',
+        depends=['account_invoice_stock'])
     Pool.register(
         product.ProductCostHistory,
         module='product_cost_warehouse', type_='model',
