@@ -221,7 +221,7 @@ class CostPriceRevision(metaclass=PoolMeta):
         pool = Pool()
         Company = pool.get('company.company')
         company_id = cls.default_company()
-        if company_id:
+        if company_id is not None and company_id >= 0:
             company = Company(company_id)
             if company.cost_price_warehouse:
                 return Transaction().context.get('warehouse')
